@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.0-8
+# Application Name - Health Check V0.5.0-9
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -53,6 +53,7 @@ gtk.gdk.threads_init()
 # the variable in a function, but this works.... Example: http://www.wellho.net/resources/ex.php4?item=y105/locvar.py
 # Setting it to "location" for now.
 var_g_GPS = "location"
+var_g_ALT = "altitude"
 
 class Ui_MainWindow(object):
     def setupUi(self, MainWindow):
@@ -238,12 +239,25 @@ class Ui_MainWindow(object):
         self.lbl_GpsPos.setObjectName("lbl_GpsPos")
         self.lbl_GpsPos.setText("GPS Position")
         
+        # Set up the GPS Info label
+        #self.lbl_alt = QtGui.QLabel(self.tab_2)
+        #self.lbl_alt.setGeometry(QtCore.QRect(10, 90, 190, 21))
+        #self.lbl_alt.setFont(font)
+        #self.lbl_alt.setObjectName("lbl_alt")
+        #self.lbl_alt.setText("GPS Altitude")
+        
         # GPS Info Field
         self.lbl_Gps_Info = QtGui.QLabel(self.tab_2)
         self.lbl_Gps_Info.setGeometry(QtCore.QRect(220, 60, 420, 21))
         self.lbl_Gps_Info.setObjectName("lbl_Gps_Info")
         self.lbl_Gps_Info.setFont(font)
 
+        # GPS Info Field
+        #self.lbl_Alt_Info = QtGui.QLabel(self.tab_2)
+        #self.lbl_Alt_Info.setGeometry(QtCore.QRect(220, 90, 420, 21))
+        #self.lbl_Alt_Info.setObjectName("lbl_Alt_Info")
+        #self.lbl_Alt_Info.setFont(font)
+
         # This label is for the phone signal (Label only)
         self.lbl_Psignal = QtGui.QLabel(self.tab_2)
         self.lbl_Psignal.setGeometry(QtCore.QRect(10, 240, 190, 21))
@@ -326,7 +340,7 @@ class Ui_MainWindow(object):
 
         # This label is used to show the Front Camera widget
         self.lbl_CameraShow = QtGui.QLabel(self.tab_3)
-        self.lbl_CameraShow.setGeometry(QtCore.QRect(150, 10, 631, 341))
+        self.lbl_CameraShow.setGeometry(QtCore.QRect(150, 10, 455, 341))
         self.lbl_CameraShow.setFrameShape(QtGui.QFrame.Panel)
         self.lbl_CameraShow.setFrameShadow(QtGui.QFrame.Raised)
         self.lbl_CameraShow.setLineWidth(2)
@@ -351,7 +365,7 @@ class Ui_MainWindow(object):
 
         # Setup and draw the button
         self.pushButton_reboot = QtGui.QPushButton(self.tab_4)
-        self.pushButton_reboot.setGeometry(QtCore.QRect(10, 10, 371, 41))
+        self.pushButton_reboot.setGeometry(QtCore.QRect(10, 10, 371, 51))
         self.pushButton_reboot.setObjectName("pushButton_reboot")
         self.pushButton_reboot.setText("System Reboot")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
@@ -369,7 +383,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.0-8 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.0-9 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -399,6 +413,8 @@ class Ui_MainWindow(object):
 # Funtion - update GPS - Using lib-location
     def updateGPS(self):
         global var_g_GPS
+        global var_g_ALT
+        
         # Start of the GPS Location information
         # Please visit here for more information and code on PyMaemo GPS API - http://wiki.maemo.org/PyMaemo/Using_Location_API
 
@@ -420,17 +436,17 @@ class Ui_MainWindow(object):
         
         # Set the GPS tabel text       
         self.lbl_Gps_Info.setText(var_g_GPS)
+        #self.lbl_Alt_Info.setText(var_g_ALT)
 
 
     def reboot_sys(self):
        
         # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
         b = None
-        # X-term - grab 10 buffered front camera images, and throw them into an image file.
-        # Everyone recommends 1.... but 10 gave more light! - so i used it :D
-        b = os.popen('sudo /sbin/reboot')
+        b = os.popen('run-standalone.sh dbus-send --system --type=method_call --dest="com.nokia.dsme" --print-reply "/com/nokia/dsme/request" com.nokia.dsme.request.req_reboot')
         b.close ()
         
+        
 # Funtion - update the front camera image
     def updateImage(self):
        
@@ -549,6 +565,9 @@ class Ui_MainWindow(object):
         f.close()
         self.lbl_Accel_Info.setText(str(coords))
 
+
+
+
 # Funtion - update rootfs, currently shows free MB and used %.
     def updaterootfs(self):
         # Call the x-terminal command to read the rootfs free space
@@ -611,7 +630,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.0-8", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.0-9", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
@@ -701,20 +720,26 @@ def on_error(control, error, user_data):
 # Moved out of the class by me
 def on_changed(device, data):
     global var_g_GPS
+    global var_g_ALT
     if not device:
         var_g_GPS = "No GPS Found"
+        var_g_ALT = ""
         return
     if device.fix:
         if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
             #Set our global variable as the location information! - scroll backup to see where it was used
             var_g_GPS = "lat = %f, long = %f" % device.fix[4:6]
+            #print "altitude = %f" % device.fix[7]
+            #print device.fix
             #print device.fix[4:6]
             #Seems to struggle with doing it once.... so do it 5 times to warm it up!
         for i in range(1, 4):
             if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
                 var_g_GPS = "lat = %f, long = %f" % device.fix[4:6]
-        #if device.fix[1] & location.GPS_DEVICE_ALTITUDE_SET:
-            #print "alt = %f" % device.fix[7]
+                #print "horizontal accuracy: %f meters" % (device.fix[6] / 100)
+            if device.fix[1] & location.GPS_DEVICE_ALTITUDE_SET:
+                var_g_ALT = "altitude = %f" % device.fix[7]
+                #print "altitude = %f" % device.fix[7]
 
             data.stop()
 
